import sys
from quasar.launcher import Launcher


def main():
    Launcher().launch()


if __name__ == "__main__":
    sys.exit(main())

